@@ -340,7 +340,7 @@ _SWITCHOVER_USAGE_
     COMMON_MS0036       => "指定された PGPATH ([0]) に PostgreSQL コマンドが存在しません\n".
                            "環境設定ファイル (pg-rex_tools.conf) の PGPATH を環境にあわせて設定してください\n",
     COMMON_MS0037       => "PostgreSQL [0] には対応していません\n".
-                           "PostgreSQL 9.4 を使用してください\n",
+                           "PostgreSQL 9.4 または 9.5 を使用してください\n",
     COMMON_MS0038       => "Pacemaker [0] には対応していません\n".
                            "Pacemaker 1.1 を使用してください\n",
     COMMON_MS0039       => "[0] で bindnetaddr ([1]) に対応するネットワークインタフェースが見つかりませんでした\n",
